@@ -1,11 +1,15 @@
 from os import path
 from urllib import request
 from rdflib import util, Graph
+import sys
 
-VERSION = "2.8.5"
-APP_DIR = path.dirname(path.realpath(__file__))
-TEMPLATES_DIR = path.join(path.dirname(path.realpath(__file__)), "templates")
-STYLE_DIR = path.join(path.dirname(path.realpath(__file__)), "style")
+# set APP_DIR to EXE folder if being called within pyinstaller EXE
+if getattr(sys, "frozen", False) and hasattr(sys, "_MEIPASS"):
+    APP_DIR = sys._MEIPASS
+else:  # use normal Python pathing
+    APP_DIR = path.dirname(path.realpath(__file__))
+TEMPLATES_DIR = path.join(APP_DIR, "templates")
+STYLE_DIR = path.join(APP_DIR, "style")
 RDF_FILE_EXTENSIONS = [".rdf", ".owl", ".ttl", ".n3", ".nt", ".json"]
 RDF_SERIALIZER_MAP = {
     "text/turtle": "turtle",
@@ -25,12 +29,22 @@ RDF_SERIALIZER_MAP = {
     "text/plain": "nt",  # text/plain is the old/deprecated mimetype for n-triples
 }
 
-
-from .profiles import OntDoc, Prof, VocPub, PROFILES
+from .profiles import OntDoc, Prof, VocPub, NMPF, PROFILES
 
 
 class MakeDocco:
-    def __init__(self, input_data_file=None, input_uri=None, data=None, outputformat="html", include_css=True, get_curies_online=False, profile="ontdoc"):
+    def __init__(
+            self,
+            input_data_file=None,
+            input_uri=None,
+            data=None,
+            outputformat="html",
+            include_css=True,
+            use_curies_stored=True,
+            get_curies_online=False,
+            profile="ontdoc",
+            language="en"
+    ):
         """This class receives all of the variables needed to specify how to make documentation from an input RDF source
 
         :param input_data_file: An RDF file
@@ -39,24 +53,29 @@ class MakeDocco:
         :type input_uri: A URI (string)
         :param data: RDF data
         :type data: Python varaible (string)
-        :param outputformat: The desired output format form the list of supported formats (currently either "html" (default) or "md" for Markdown
-        :type outputformat: string (one of "html" or "md")
+        :param outputformat: The desired output format from the list of supported formats ("html" (default),
+                            "md" - Markdown or "adoc" - ASCII Doc
+        :type outputformat: string (one of "html" or "md" or "adoc")
         :param include_css: Whether (True, default) or not (False) to include styling CSS within HTML outputs
         :type include_css: boolean
         :param get_curies_online: Whether (True) or not (False, default) to search prefix.cc online for additional URI prefixes
         :type get_curies_online: boolean
         :param profile: When document profile, from a supported set, to use. Currently supported is "ontdoc" (profile of OWL) or "skosp" (profile of SKOS). See `list_profiles()` for full list of profiles.
-        :type profile: string (one of "ontdoc" or "skosp")
+        :type profile: string (one of "ontdoc", "skosp" or "prof")
+        :param language: ISO 639 code for the desired output language
+        :type language: string
         """
         self.profile_selected = profile
 
-        if outputformat not in ["html", "md"]:
+        if outputformat not in ["html", "md", "adoc"]:
             self.outputformat = "html"
         else:
             self.outputformat = outputformat
 
         self.include_css = include_css
+        self.use_curies_stored = use_curies_stored
         self.get_curies_online = get_curies_online
+        self.language = language
 
         if profile not in PROFILES.keys():
             print("The profile you've selected, {}, is not recognised so the default profile, {} is being used. "
@@ -150,16 +169,28 @@ class MakeDocco:
                 self.source_info,
                 outputformat=self.outputformat,
                 include_css=self.include_css,
-                default_language="en",
+                default_language=self.language,
+                use_curies_stored=self.use_curies_stored,
                 get_curies_online=self.get_curies_online
             )
         elif self.profile_selected == "vocpub":
             p = VocPub(
+                self.G,
+                self.source_info,
+                outputformat=self.outputformat,
+                include_css=self.include_css,
+                default_language=self.language,
+                use_curies_stored=self.use_curies_stored,
+                get_curies_online=self.get_curies_online
+            )
+        elif self.profile_selected == "nmpf":
+            p = NMPF(
                 self.G,
                 self.source_info,
                 outputformat=self.outputformat,
                 include_css=self.include_css,
                 default_language="en",
+                use_curies_stored=self.use_curies_stored,
                 get_curies_online=self.get_curies_online
             )
         else:
@@ -168,14 +199,15 @@ class MakeDocco:
                 self.source_info,
                 outputformat=self.outputformat,
                 include_css=self.include_css,
-                default_language="en",
+                default_language=self.language,
+                use_curies_stored=self.use_curies_stored,
                 get_curies_online=self.get_curies_online
             )
 
         if destination is not None:
             doc = p.generate_document()
             try:
-                with open(destination, "w") as f:
+                with open(destination, "w", encoding="utf8") as f:
                     f.write(doc)
             except Exception as e:
                 print(e)
