@@ -1,5 +1,5 @@
-from os import path
-from pylode.common import VERSION, TEMPLATES_DIR, STYLE_DIR
+from pylode import __version__
+from pylode.common import TEMPLATES_DIR, STYLE_DIR
 import collections
 from os import path
 from itertools import chain
@@ -12,8 +12,24 @@ from pylode.profiles.base import BaseProfile
 
 
 class OntDoc(BaseProfile):
-    def __init__(self, g, source_info, outputformat="html", include_css=False, default_language="en", get_curies_online=False):
-        super().__init__(g, source_info, outputformat=outputformat, include_css=include_css, get_curies_online=False, default_language=default_language)
+    def __init__(
+            self,
+            g,
+            source_info,
+            outputformat="html",
+            include_css=False,
+            default_language="en",
+            use_curies_stored=True,
+            get_curies_online=False
+    ):
+        super().__init__(
+            g,
+            source_info,
+            outputformat=outputformat,
+            include_css=include_css,
+            use_curies_stored=use_curies_stored,
+            get_curies_online=get_curies_online,
+            default_language=default_language)
         self.G.bind("prov", PROV)
         self.CLASSES = collections.OrderedDict()
         self.PROPERTIES = collections.OrderedDict()
@@ -54,15 +70,15 @@ class OntDoc(BaseProfile):
                             # domain collections (unionOf | intersectionOf
                             q = '''
                                 PREFIX owl:  <http://www.w3.org/2002/07/owl#>
-                                PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>  
+                                PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
 
                                 SELECT ?col_type ?col_member
                                 WHERE {{
-                                    <{}> rdfs:domain ?domain .  
+                                    <{}> rdfs:domain ?domain .
                                     ?domain owl:unionOf|owl:intersectionOf ?collection .
-                                    ?domain ?col_type ?collection . 
-                                    ?collection rdf:rest*/rdf:first ?col_member .              
-                                }} 
+                                    ?domain ?col_type ?collection .
+                                    ?collection rdf:rest*/rdf:first ?col_member .
+                                }}
                             '''.format(s)
                             collection_type = None
                             collection_members = []
@@ -70,22 +86,22 @@ class OntDoc(BaseProfile):
                                 collection_type = self._get_curie(str(r.col_type))
                                 collection_members.append(str(r.col_member))
                             domains.append((collection_type, collection_members))
-                    self.PROPERTIES[prop]['domains'] = domains                
+                    self.PROPERTIES[prop]['domains'] = domains
 
                     """
                     if type(o2) == BNode:
                         # onClass collections (unionOf | intersectionOf
                         q = """
                             PREFIX owl:  <http://www.w3.org/2002/07/owl#>
-                            PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>  
+                            PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
 
                             SELECT ?col_type ?col_member
                             WHERE {{
-                                <{}> owl:onClass ?onClass .  
+                                <{}> owl:onClass ?onClass .
                                 ?onClass owl:unionOf|owl:intersectionOf ?collection .
-                                ?onClass ?col_type ?collection . 
-                                ?collection rdf:rest*/rdf:first ?col_member .              
-                            }} 
+                                ?onClass ?col_type ?collection .
+                                ?collection rdf:rest*/rdf:first ?col_member .
+                            }}
                         """.format(
                             str(subject)
                         )
@@ -115,7 +131,7 @@ class OntDoc(BaseProfile):
                     elif p2 in [OWL.cardinality, OWL.qualifiedCardinality]:
                         card = "exactly"
 
-                    if self.outputformat == "md":
+                    if self.outputformat in ["md", "adoc"]:
                         card = '**{}** {}'.format(
                             card, str(o2)
                         )
@@ -133,16 +149,16 @@ class OntDoc(BaseProfile):
                         # someValuesFrom collections (unionOf | intersectionOf
                         q = """
                             PREFIX owl:  <http://www.w3.org/2002/07/owl#>
-                            PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>  
+                            PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
 
                             SELECT ?col_type ?col_member
                             WHERE {{
                                 <{0}> ?x _:{1} .
                                 _:{1} owl:someValuesFrom|owl:allValuesFrom ?bn2 .
                                 ?bn2 owl:unionOf|owl:intersectionOf ?collection .
-                                ?s ?col_type ?collection . 
-                                ?collection rdf:rest*/rdf:first ?col_member .              
-                            }} 
+                                ?s ?col_type ?collection .
+                                ?collection rdf:rest*/rdf:first ?col_member .
+                            }}
                         """.format(
                             str(subject), str(o2)
                         )
@@ -158,12 +174,12 @@ class OntDoc(BaseProfile):
                     else:
                         c = self._make_formatted_uri(str(o2), type="c")
 
-                    if self.outputformat == "md":
+                    if self.outputformat in ["md", "adoc"]:
                         card = '**{}** {}'.format(card, c)
                     else:
                         card = '<span class="cardinality">{}</span> {}'.format(card, c)
                 elif p2 == OWL.hasValue:
-                    if self.outputformat == "md":
+                    if self.outputformat in ["md", "adoc"]:
                         card = '**value** {}'.format(
                             self._make_formatted_uri(str(o2), type="c")
                         )
@@ -180,68 +196,50 @@ class OntDoc(BaseProfile):
     def _load_template(self, template_file):
         return Environment(loader=FileSystemLoader(join(TEMPLATES_DIR, "ontdoc"))).get_template(template_file)
 
-    def _make_formatted_uri(self, uri, type=None):
-        # set display to CURIE
-        short = self._get_curie(uri)
-        # if the URI base is within the default namespace of this ontology
-        #   use the fragment URI
-        # else
-        #   use the given URI
-        uri_base = self._get_namespace_from_uri(uri)
-        link = None
-        if uri_base == self.METADATA.get("default_namespace"):
+    def _make_fragment_uri(self, uri):
+        """OntDoc Profile allows fragment URIs for Classes & Properties"""
+        if self.PROPERTIES.get(uri) or self.CLASSES.get(uri):
             if self.PROPERTIES.get(uri):
-                link = "[{}]({})".format(short, self.PROPERTIES[uri]["fid"]) \
-                    if self.outputformat == "md" \
-                    else '<a href="#{}">{}</a>'.format(self.PROPERTIES[uri]["fid"], short)
+                title = self.PROPERTIES[uri]["title"] \
+                    if self.PROPERTIES[uri].get("title") is not None else self.PROPERTIES[uri]["fid"]
+                uri = self.PROPERTIES[uri]["fid"]
             elif self.CLASSES.get(uri):
-                link = "[{}]({})".format(short, self.CLASSES[uri]["fid"]) \
-                    if self.outputformat == "md" \
-                    else '<a href="#{}">{}</a>'.format(self.CLASSES[uri]["fid"], short)
-            else:
-                link = "[{}]({})".format(short, uri) \
-                    if self.outputformat == "md" \
-                    else '<a href="{}">{}</a>'.format(uri, short)
+                title = self.CLASSES[uri]["title"] \
+                    if self.CLASSES[uri].get("title") is not None else self.CLASSES[uri]["fid"]
+                uri = self.CLASSES[uri]["fid"]
 
-        if link is None:
-            link = "[{}]({})".format(short, uri) \
-                if self.outputformat == "md" \
-                else '<a href="{}">{}</a>'.format(uri, short)
+            links = {
+                "md": f"[{title}](#{uri})",
+                "adoc": f"link:#{uri}[{title}]",
+                "html": f'<a href="#{uri}">{title}</a>'
+            }
 
-        if type == "c":
-            if self.outputformat == "md":
-                suffix = ' (c)'
-            else:
-                suffix = '<sup class="sup-c" title="class">c</sup>'
-        elif type == "op":
-            if self.outputformat == "md":
-                suffix = ' (op)'
-            else:
-                suffix = '<sup class="sup-op" title="object property">op</sup>'
-        elif type == "fp":
-            if self.outputformat == "md":
-                suffix = ' (fp)'
-            else:
-                suffix = '<sup class="sup-fp" title="functional property">fp</sup>'
-        elif type == "dp":
-            if self.outputformat == "md":
-                suffix = ' (dp)'
-            else:
-                suffix = '<sup class="sup-dp" title="datatype property">dp</sup>'
-        elif type == "ap":
-            if self.outputformat == "md":
-                suffix = ' (ap)'
-            else:
-                suffix = '<sup class="sup-ap" title="annotation property">ap</sup>'
-        elif type == "ni":
-            if self.outputformat == "md":
-                suffix = ' (ni)'
-            else:
-                suffix = '<sup class="sup-ni" title="named individual">ni</sup>'
+            return links[self.outputformat]
         else:
-            suffix = ''
+            return self._make_formatted_uri_basic(uri)
 
-        return link + suffix
+    def _make_formatted_uri(self, uri, type=None):
+        link = super()._make_formatted_uri(uri)
+
+        types = {
+            "c": "class",
+            "op": "object property",
+            "fp": "functional property",
+            "dp": "datatype property",
+            "ap": "annotation property",
+            "ni": "named individual"
+        }
+
+        if type not in types.keys():
+            return link
+
+        suffixes = {
+            "md": f' ({type})',
+            "adoc": f' ^{type}^',
+            "html": f'<sup class="sup-{type}" title="{types[type]}">{type}</sup>'  # {}
+        }
+
+        return link + suffixes[self.outputformat]
 
     def _expand_graph(self):
         # name
@@ -354,10 +352,20 @@ class OntDoc(BaseProfile):
                     self.METADATA["title"] = str(o)
 
                 if p == DCTERMS.description:
-                    self.METADATA["description"] = markdown.markdown(str(o))
+                    if self.outputformat == "md":
+                        self.METADATA["description"] = str(o)
+                    elif self.outputformat == "adoc":
+                        self.METADATA["description"] = str(o)
+                    else:
+                        self.METADATA["description"] = markdown.markdown(str(o))
 
                 if p == SKOS.historyNote:
-                    self.METADATA["historyNote"] = markdown.markdown(str(o))
+                    if self.outputformat == "md":
+                        self.METADATA["historyNote"] = str(o)
+                    elif self.outputformat == "adoc":
+                        self.METADATA["historyNote"] = str(o)
+                    else:
+                        self.METADATA["historyNote"] = markdown.markdown(str(o))
 
                 # dates
                 if p in [DCTERMS.created, DCTERMS.modified, DCTERMS.issued]:
@@ -405,7 +413,7 @@ class OntDoc(BaseProfile):
                     if type(o) == Literal:
                         self.METADATA[agent_type].add(str(o))
                     else:  # Blank Node or URI
-                        self.METADATA[agent_type].add(self._make_agent_html(o))
+                        self.METADATA[agent_type].add(self._make_agent(o))
 
                 if p == PROV.wasGeneratedBy:
                     for o2 in self.G.objects(subject=o, predicate=DOAP.repository):
@@ -443,7 +451,9 @@ class OntDoc(BaseProfile):
         for cls in self.CLASSES.keys():
             s = URIRef(cls)
             # create Python dict for each class
-            self.CLASSES[cls] = {}
+            self.CLASSES[cls] = {
+                "iri": cls
+            }
 
             # basic class properties
             self.CLASSES[cls]["title"] = None
@@ -458,10 +468,20 @@ class OntDoc(BaseProfile):
                     self.CLASSES[cls]["title"] = str(o)
 
                 if p == DCTERMS.description:
-                    self.CLASSES[cls]["description"] = markdown.markdown(str(o))
+                    if self.outputformat == "md":
+                        self.CLASSES[cls]["description"] = str(o)
+                    elif self.outputformat == "adoc":
+                        self.CLASSES[cls]["description"] = str(o)
+                    else:
+                        self.CLASSES[cls]["description"] = markdown.markdown(str(o))
 
                 if p == SKOS.scopeNote:
-                    self.CLASSES[cls]["scopeNote"] = markdown.markdown(str(o))
+                    if self.outputformat == "md":
+                        self.CLASSES[cls]["scopeNote"] = str(o)
+                    elif self.outputformat == "adoc":
+                        self.CLASSES[cls]["scopeNote"] = str(o)
+                    else:
+                        self.CLASSES[cls]["scopeNote"] = markdown.markdown(str(o))
 
                 if p == SKOS.example:
                     self.CLASSES[cls]["example"] = str(o)
@@ -471,7 +491,7 @@ class OntDoc(BaseProfile):
 
                 if p == DCTERMS.source or p == DC.source:
                     if str(o).startswith('http'):
-                        self.CLASSES[cls]["source"] = self._make_formatted_uri(o)  # '<a href="{0}">{0}</a>'.format(str(o))
+                        self.CLASSES[cls]["source"] = self._make_formatted_uri(o)
                     else:
                         self.CLASSES[cls]["source"] = str(o)
 
@@ -493,15 +513,15 @@ class OntDoc(BaseProfile):
                     # equivalent classes collections (unionOf | intersectionOf
                     q = """
                         PREFIX owl:  <http://www.w3.org/2002/07/owl#>
-                        PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>  
+                        PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
 
                         SELECT ?col_type ?col_member
                         WHERE {{
-                            <{}> owl:equivalentClass ?eq .  
+                            <{}> owl:equivalentClass ?eq .
                             ?eq owl:unionOf|owl:intersectionOf ?collection .
-                            ?eq ?col_type ?collection . 
-                            ?collection rdf:rest*/rdf:first ?col_member .              
-                        }} 
+                            ?eq ?col_type ?collection .
+                            ?collection rdf:rest*/rdf:first ?col_member .
+                        }}
                     """.format(
                         s
                     )
@@ -524,15 +544,15 @@ class OntDoc(BaseProfile):
                         # super collections (unionOf | intersectionOf
                         q = """
                             PREFIX owl:  <http://www.w3.org/2002/07/owl#>
-                            PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>  
+                            PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
 
                             SELECT ?col_type ?col_member
                             WHERE {{
-                                <{}> rdfs:subClassOf ?sup .  
+                                <{}> rdfs:subClassOf ?sup .
                                 ?sup owl:unionOf|owl:intersectionOf ?collection .
-                                ?sup ?col_type ?collection . 
-                                ?collection rdf:rest*/rdf:first ?col_member .              
-                            }} 
+                                ?sup ?col_type ?collection .
+                                ?collection rdf:rest*/rdf:first ?col_member .
+                            }}
                         """.format(
                             s
                         )
@@ -557,15 +577,15 @@ class OntDoc(BaseProfile):
                     # sub classes collections (unionOf | intersectionOf
                     q = """
                         PREFIX owl:  <http://www.w3.org/2002/07/owl#>
-                        PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>  
+                        PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
 
                         SELECT ?col_type ?col_member
                         WHERE {{
-                            ?sub rdfs:subClassOf <{}> . 
+                            ?sub rdfs:subClassOf <{}> .
                             ?sub owl:unionOf|owl:intersectionOf ?collection .
-                            ?sub ?col_type ?collection . 
-                            ?collection rdf:rest*/rdf:first ?col_member .              
-                        }} 
+                            ?sub ?col_type ?collection .
+                            ?collection rdf:rest*/rdf:first ?col_member .
+                        }}
                     """.format(
                         s
                     )
@@ -598,6 +618,10 @@ class OntDoc(BaseProfile):
             self.CLASSES[cls]["in_range_includes_of"] = in_range_includes_of
 
             # TODO: cater for Named Individuals of this class - "has members"
+            has_members = []
+            for o in self.G.subjects(predicate=RDF.type, object=s):
+                has_members.append(str(o))
+            self.CLASSES[cls]["has_members"] = has_members
 
         # # sort properties by title
         # x = sorted([(k, v) for k, v in classes.items()], key=lambda tup: tup[1]['title'])
@@ -650,10 +674,20 @@ class OntDoc(BaseProfile):
                     self.PROPERTIES[prop]["title"] = str(o)
 
                 if p == DCTERMS.description:
-                    self.PROPERTIES[prop]["description"] = str(o)
+                    if self.outputformat == "md":
+                        self.PROPERTIES[prop]["description"] = str(o)
+                    elif self.outputformat == "adoc":
+                        self.PROPERTIES[prop]["description"] = str(o)
+                    else:
+                        self.PROPERTIES[prop]["description"] = markdown.markdown(str(o))
 
                 if p == SKOS.scopeNote:
-                    self.PROPERTIES[prop]["scopeNote"] = str(o)
+                    if self.outputformat == "md":
+                        self.PROPERTIES[prop]["scopeNote"] = str(o)
+                    elif self.outputformat == "adoc":
+                        self.PROPERTIES[prop]["scopeNote"] = str(o)
+                    else:
+                        self.PROPERTIES[prop]["scopeNote"] = markdown.markdown(str(o))
 
                 if p == SKOS.example:
                     self.PROPERTIES[prop]["example"] = str(o)
@@ -663,8 +697,7 @@ class OntDoc(BaseProfile):
 
                 if p == DCTERMS.source or p == DC.source:
                     if str(o).startswith('http'):
-                        self.PROPERTIES[prop]["source"] = self._make_formatted_uri(
-                            o)  # '<a href="{0}">{0}</a>'.format(str(o))
+                        self.PROPERTIES[prop]["source"] = self._make_formatted_uri(o)
                     else:
                         self.PROPERTIES[prop]["source"] = str(o)
 
@@ -705,15 +738,15 @@ class OntDoc(BaseProfile):
                     # domain collections (unionOf | intersectionOf
                     q = """
                         PREFIX owl:  <http://www.w3.org/2002/07/owl#>
-                        PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>  
+                        PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
 
                         SELECT ?col_type ?col_member
                         WHERE {{
-                            <{}> rdfs:domain ?domain .  
+                            <{}> rdfs:domain ?domain .
                             ?domain owl:unionOf|owl:intersectionOf ?collection .
-                            ?domain ?col_type ?collection . 
-                            ?collection rdf:rest*/rdf:first ?col_member .              
-                        }} 
+                            ?domain ?col_type ?collection .
+                            ?collection rdf:rest*/rdf:first ?col_member .
+                        }}
                     """.format(
                         s
                     )
@@ -734,15 +767,15 @@ class OntDoc(BaseProfile):
                     # domainIncludes collections (unionOf | intersectionOf
                     q = """
                         PREFIX owl:  <http://www.w3.org/2002/07/owl#>
-                        PREFIX sdo: <https://schema.org/>  
+                        PREFIX sdo: <https://schema.org/>
 
                         SELECT ?col_type ?col_member
                         WHERE {{
-                            <{}> sdo:domainIncludes ?domainIncludes .  
+                            <{}> sdo:domainIncludes ?domainIncludes .
                             ?domainIncludes owl:unionOf|owl:intersectionOf ?collection .
-                            ?domainIncludes ?col_type ?collection . 
-                            ?collection rdf:rest*/rdf:first ?col_member .              
-                        }} 
+                            ?domainIncludes ?col_type ?collection .
+                            ?collection rdf:rest*/rdf:first ?col_member .
+                        }}
                     """.format(
                         s
                     )
@@ -756,20 +789,20 @@ class OntDoc(BaseProfile):
             # ranges
             for o in self.G.objects(subject=s, predicate=RDFS.range):
                 if type(o) != BNode:
-                    self.PROPERTIES[prop]["ranges"].append(str(o))  # ranges that are just classes
+                    self.PROPERTIES[prop]["ranges"].append(self._make_formatted_uri(o, type="c"))  # ranges that are just classes
                 else:
-                    # range collections (unionOf | intersectionOf
+                    # range collections (unionOf | intersectionOf)
                     q = """
                         PREFIX owl:  <http://www.w3.org/2002/07/owl#>
-                        PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>  
+                        PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
 
                         SELECT ?col_type ?col_member
                         WHERE {{
-                            <{}> rdfs:range ?range .  
+                            <{}> rdfs:range ?range .
                             ?range owl:unionOf|owl:intersectionOf ?collection .
-                            ?range ?col_type ?collection . 
-                            ?collection rdf:rest*/rdf:first ?col_member .              
-                        }} 
+                            ?range ?col_type ?collection .
+                            ?collection rdf:rest*/rdf:first ?col_member .
+                        }}
                     """.format(
                         s
                     )
@@ -788,15 +821,15 @@ class OntDoc(BaseProfile):
                     # rangeIncludes collections (unionOf | intersectionOf
                     q = """
                         PREFIX owl:  <http://www.w3.org/2002/07/owl#>
-                        PREFIX sdo: <https://schema.org/>  
+                        PREFIX sdo: <https://schema.org/>
 
                         SELECT ?col_type ?col_member
                         WHERE {{
-                            <{}> sdo:rangeIncludes ?rangeIncludes .  
+                            <{}> sdo:rangeIncludes ?rangeIncludes .
                             ?rangeIncludes owl:unionOf|owl:intersectionOf ?collection .
-                            ?rangeIncludes ?col_type ?collection . 
-                            ?collection rdf:rest*/rdf:first ?col_member .              
-                        }} 
+                            ?rangeIncludes ?col_type ?collection .
+                            ?collection rdf:rest*/rdf:first ?col_member .
+                        }}
                     """.format(
                         s
                     )
@@ -860,8 +893,7 @@ class OntDoc(BaseProfile):
 
                 if p == DCTERMS.source or p == DC.source:
                     if str(o).startswith('http'):
-                        self.NAMED_INDIVIDUALS[ni]["source"] = self._make_formatted_uri(
-                            o)  # '<a href="{0}">{0}</a>'.format(str(o))
+                        self.NAMED_INDIVIDUALS[ni]["source"] = self._make_formatted_uri(o)
                     else:
                         self.NAMED_INDIVIDUALS[ni]["source"] = str(o)
 
@@ -907,54 +939,60 @@ class OntDoc(BaseProfile):
             has_nis=self.METADATA.get("has_nis"),
         )
 
-    def _make_classes(self):
-        # make all Classes
+    def _make_class(self, uri, class_):
         class_template = self._load_template("class." + self.outputformat)
+        # handling Markdown formatting within a table
+        if self.outputformat == "md":
+            desc = class_["description"].replace("\n", " ") if class_.get("description") is not None else None
+            if class_.get("example") is not None:
+                eg = class_["example"].strip().replace("\t", "    ").split("\n")
+                eg2 = ""
+                for line in eg:
+                    eg2 += "`" + line + "`<br />"
+                eg = eg2
+            else:
+                eg = None
+        elif self.outputformat == "adoc":
+            desc = class_["description"]
+            eg = class_["example"]
+        else:
+            desc = class_["description"]
+            eg = class_["example"].replace("<", "&lt;").replace(">", "&gt;") if class_.get("example") is not None else None
+
+        return class_template.render(
+            uri=uri,
+            fid=class_["fid"],
+            title=class_["title"],
+            description=desc,
+            supers=class_["supers"],
+            restrictions=class_["restrictions"],
+            scopeNote=class_["scopeNote"],
+            example=eg,
+            is_defined_by=class_["isDefinedBy"],
+            source=class_["source"],
+            subs=class_["subs"],
+            in_domain_of=class_["in_domain_of"],
+            in_domain_includes_of=class_["in_domain_includes_of"],
+            in_range_of=class_["in_range_of"],
+            in_range_includes_of=class_["in_range_includes_of"],
+            has_members=class_["has_members"]
+        )
+
+    def _make_classes(self):
+        # make all the individual Classes
         classes_list = []
         for k, v in self.CLASSES.items():
-            # handling Markdown formatting within a table
-            if self.outputformat == "md":
-                desc = v["description"].replace("\n", " ") if v.get("description") is not None else None
-                if v.get("example") is not None:
-                    eg = v["example"].strip().replace("\t", "    ").split("\n")
-                    eg2 = ""
-                    for line in eg:
-                        eg2 += "`" + line + "`<br />"
-                    eg = eg2
-                else:
-                    eg = None
-            else:
-                desc = v["description"]
-                eg = v["example"].replace("<", "&lt;").replace(">", "&gt;") if v.get("example") is not None else None
-
-            classes_list.append(
-                class_template.render(
-                    uri=k,
-                    fid=v["fid"],
-                    title=v["title"],
-                    description=desc,
-                    supers=v["supers"],
-                    restrictions=v["restrictions"],
-                    scopeNote=v["scopeNote"],
-                    example=eg,
-                    is_defined_by=v["isDefinedBy"],
-                    source=v["source"],
-                    subs=v["subs"],
-                    in_domain_of=v["in_domain_of"],
-                    in_domain_includes_of=v["in_domain_includes_of"],
-                    in_range_of=v["in_range_of"],
-                    in_range_includes_of=v["in_range_includes_of"],
-                )
-            )
+            classes_list.append(self._make_class(k, v))
 
         # make the template for all Classes
         classes_template = self._load_template("classes." + self.outputformat)
         # add in Class index
-        fids = sorted(
-            [(v.get("fid"), v.get("title")) for k, v in self.CLASSES.items()],
-            key=lambda tup: tup[1],
-        )
-        return classes_template.render(fids=fids, classes=classes_list, )
+        # fids = sorted(
+        #     [(v.get("fid"), v.get("title")) for k, v in self.CLASSES.items()],
+        #     key=lambda tup: tup[1],
+        # )
+        class_index = [self._make_formatted_uri(x) for x in self.CLASSES.keys()]
+        return classes_template.render(class_index=class_index, classes=classes_list, )
 
     def _make_property(self, property):
         # handling Markdown formatting within a table
@@ -969,6 +1007,9 @@ class OntDoc(BaseProfile):
                 eg = eg2
             else:
                 eg = None
+        elif self.outputformat == "adoc":
+            desc = property[1].get("description")
+            eg = property[1].get("example")
         else:
             desc = property[1].get("description")
             eg = property[1].get("example")
@@ -1066,7 +1107,6 @@ class OntDoc(BaseProfile):
         )
 
     def _make_named_individuals(self):
-        # make all NIs
         named_individuals_list = []
         for k, v in self.NAMED_INDIVIDUALS.items():
             named_individuals_list.append(
@@ -1100,7 +1140,7 @@ class OntDoc(BaseProfile):
             default_namespace=self.METADATA["default_namespace"],
             namespaces=self._make_namespaces(),
             css=css,
-            pylode_version=VERSION
+            pylode_version=__version__
         )
 
     def generate_document(self):
@@ -1190,9 +1230,9 @@ class OntDoc(BaseProfile):
             for d in prop["ranges"]:
                 if type(d) == tuple:
                     for m in d[1]:
-                        html.append(self._make_formatted_uri(m, type="c"))
+                        html.append(m)
                 else:
-                    html.append(self._make_formatted_uri(d, type="c"))
+                    html.append(d)
             self.PROPERTIES[uri]["ranges"] = html
 
             html = []
@@ -1277,4 +1317,14 @@ class OntDoc(BaseProfile):
                 html.append(self._make_formatted_uri(p, type=prop_type))
             self.CLASSES[uri]["in_range_includes_of"] = html
 
+            html = []
+            for p in cls["has_members"]:
+                prop_type = (
+                    self.PROPERTIES.get(p).get("prop_type")
+                    if self.PROPERTIES.get(p)
+                    else None
+                )
+                html.append(self._make_formatted_uri(p, type=prop_type))
+            self.CLASSES[uri]["has_members"] = html
+
         return self._make_document()
